@@ -27,6 +27,8 @@ pub mod types;
 pub mod error;
 pub mod proxy;
 pub mod dbase;
+#[cfg(feature = "serde")]
+pub mod serde;
 
 pub use types::*;
 pub use error::*;
